@@ -75,6 +75,7 @@ class MessageProcessor:
         self.web_ui_messages = set()  # Track messages from web UI to avoid duplicates
         self.pending_input_message_id = None  # Track if we're waiting for input
         self.last_was_tool_use = False  # Track if last assistant message used tools
+        self.subtask = False
 
     def process_user_message_sync(self, content: str, from_web: bool) -> None:
         """Process a user message (sync version for monitor thread)"""
@@ -215,7 +216,7 @@ class ClaudeWrapperV3:
             sys.exit(1)
 
         self.base_url = base_url or os.environ.get(
-            "OMNARA_BASE_URL", "https://agent-dashboard-mcp.onrender.com"
+            "OMNARA_BASE_URL", "https://agent.omnara.com"
         )
         self.omnara_client_async: Optional[AsyncOmnaraClient] = None
         self.omnara_client_sync: Optional[OmnaraClient] = None
@@ -285,8 +286,10 @@ class ClaudeWrapperV3:
             OMNARA_WRAPPER_LOG_DIR.mkdir(exist_ok=True, parents=True)
             log_file_path = OMNARA_WRAPPER_LOG_DIR / f"{self.agent_instance_id}.log"
             self.debug_log_file = open(log_file_path, "w")
+            timestamp = time.strftime("%Y-%m-%d %H:%M:%S")
+            milliseconds = int((time.time() % 1) * 1000)
             self.log(
-                f"=== Claude Wrapper V3 Debug Log - {time.strftime('%Y-%m-%d %H:%M:%S')} ==="
+                f"=== Claude Wrapper V3 Debug Log - {timestamp}.{milliseconds:03d} ==="
             )
         except Exception as e:
             print(f"Failed to create debug log file: {e}", file=sys.stderr)
@@ -323,7 +326,11 @@ class ClaudeWrapperV3:
         """Write to debug log file"""
         if self.debug_log_file:
             try:
-                self.debug_log_file.write(f"[{time.strftime('%H:%M:%S')}] {message}\n")
+                timestamp = time.strftime("%Y-%m-%d %H:%M:%S")
+                milliseconds = int((time.time() % 1) * 1000)
+                self.debug_log_file.write(
+                    f"[{timestamp}.{milliseconds:03d}] {message}\n"
+                )
                 self.debug_log_file.flush()
             except Exception:
                 pass
@@ -333,14 +340,23 @@ class ClaudeWrapperV3:
         if not self.api_key:
             raise ValueError("API key is required to initialize Omnara clients")
 
-        # Initialize sync client
+        # ~24 hours of retries: 6 exponential (63s) + 1438 at 60s each = 1444 total
         self.omnara_client_sync = OmnaraClient(
-            api_key=self.api_key, base_url=self.base_url
+            api_key=self.api_key,
+            base_url=self.base_url,
+            max_retries=1440,  # ~24 hours with 60s cap
+            backoff_factor=1.0,
+            backoff_max=60.0,
+            log_func=self.log,
         )
 
-        # Initialize async client (we'll ensure session when needed)
         self.omnara_client_async = AsyncOmnaraClient(
-            api_key=self.api_key, base_url=self.base_url
+            api_key=self.api_key,
+            base_url=self.base_url,
+            max_retries=1440,  # ~24 hours with 60s cap
+            backoff_factor=1.0,
+            backoff_max=60.0,
+            log_func=self.log,
         )
 
     def _heartbeat_loop(self):
@@ -478,6 +494,13 @@ class ClaudeWrapperV3:
         try:
             msg_type = data.get("type")
 
+            # We skip showing messages from subtasks
+            is_subtask = data.get("isSidechain")
+            if is_subtask and (msg_type == "assistant" or msg_type == "user"):
+                return
+            elif not is_subtask and (msg_type == "assistant" or msg_type == "user"):
+                self.message_processor.subtask = False
+
             if msg_type == "user":
                 # Skip meta messages (like "Caveat:" messages)
                 if data.get("isMeta", False):
@@ -553,6 +576,8 @@ class ClaudeWrapperV3:
                             # Track if this was a tool use
                             if block.get("type") == "tool_use":
                                 tools_used.append(formatted_content)
+                            if block.get("name") == "Task":
+                                self.message_processor.subtask = True
 
                 # Process message if we have content
                 if formatted_parts:
@@ -881,6 +906,9 @@ class ClaudeWrapperV3:
                 # Use select to multiplex I/O
                 rlist, _, _ = select.select([sys.stdin, self.master_fd], [], [], 0.01)
 
+                clean_buffer = re.sub(
+                    r"\x1b\[[0-9;]*[a-zA-Z]", "", self.terminal_buffer
+                )
                 # When expecting permission prompt, check if we need to handle it
                 if self.message_processor.last_was_tool_use and self.is_claude_idle():
                     # After tool use + idle, assume permission prompt is shown
@@ -889,12 +917,6 @@ class ClaudeWrapperV3:
 
                     # After 0.5 seconds, check if we can parse the prompt from buffer
                     elif time.time() - self._permission_assumed_time > 0.5:
-                        # Clean the buffer to check for content
-
-                        clean_buffer = re.sub(
-                            r"\x1b\[[0-9;]*[a-zA-Z]", "", self.terminal_buffer
-                        )
-
                         # If we see permission/plan prompt, extract it
                         # For plan mode: "Would you like to proceed" without "(esc"
                         # For permission: "Do you want" with "(esc"
@@ -957,19 +979,36 @@ class ClaudeWrapperV3:
                         elif time.time() - self._permission_assumed_time > 1.0:
                             if not hasattr(self, "_permission_handled"):
                                 self._permission_handled = True
-                            if self.agent_instance_id and self.omnara_client_sync:
-                                response = self.omnara_client_sync.send_message(
-                                    content="Waiting for your input...",
-                                    agent_type=self.name,
-                                    agent_instance_id=self.agent_instance_id,
-                                    requires_user_input=False,
-                                )
-                                self.message_processor.last_message_id = (
-                                    response.message_id
-                                )
-                                self.message_processor.last_message_time = time.time()
-                                self.message_processor.last_was_tool_use = False
-
+                                with self.send_message_lock:
+                                    if (
+                                        self.agent_instance_id
+                                        and self.omnara_client_sync
+                                    ):
+                                        response = self.omnara_client_sync.send_message(
+                                            content="Waiting for your input...",
+                                            agent_type=self.name,
+                                            agent_instance_id=self.agent_instance_id,
+                                            requires_user_input=False,
+                                        )
+                                        self.message_processor.last_message_id = (
+                                            response.message_id
+                                        )
+                                        self.message_processor.last_message_time = (
+                                            time.time()
+                                        )
+                                        self.message_processor.last_was_tool_use = False
+                elif (
+                    (
+                        ("Do you want" in clean_buffer and "(esc" in clean_buffer)
+                        or (
+                            "Would you like to proceed" in clean_buffer
+                            and "No, keep planning" in clean_buffer
+                        )
+                    )
+                    and self.message_processor.subtask
+                    and not self.pending_permission_options
+                ):
+                    self.message_processor.last_was_tool_use = True
                 else:
                     # Clear state when conditions change
                     if hasattr(self, "_permission_assumed_time"):
